@@ -1,6 +1,6 @@
 
 package Importer::Zim::Bogus;
-$Importer::Zim::Bogus::VERSION = '0.10.0';
+$Importer::Zim::Bogus::VERSION = '0.11.0';
 # ABSTRACT: Bogus Importer::Zim backend
 
 use 5.010001;
@@ -20,9 +20,24 @@ sub import {
     my @exports = $class->_prepare_args(@_);
 
     my $caller = caller;
+    return _export_to(    #
+        map { ; "${caller}::$_->{export}" => $_->{code} } @exports
+    );
+}
+
+sub export_to {
+    my $t = shift;
+    @_ = %{ $_[0] } if @_ == 1 && ref $_[0] eq 'HASH';
+    @_ = map { $_ & 1 ? $_[$_] : "${t}::$_[$_]" } 0 .. $#_;
+    goto &_export_to;
+}
+
+sub _export_to {
+    my %imports = @_;
+
     no strict 'refs';
-    for (@exports) {
-        *{"${caller}::$_->{export}"} = $_->{code};
+    for ( keys %imports ) {
+        *$_ = $imports{$_};
     }
 }
 
@@ -83,7 +98,7 @@ Importer::Zim::Bogus - Bogus Importer::Zim backend
 
 =head1 VERSION
 
-version 0.10.0
+version 0.11.0
 
 =head1 SYNOPSIS
 
